==> 0.8.tar.gz: 0.8/class/PM.php <==
<?php
class PM {
  // Konstruktor
  public function __construct ($class_needed,$file_ending) {
    // Die Klasse wird eingebunden
      include($class_needed.$file_ending);
    // Es wird eine Instanz der Klasse erzeugt, und "class_obj" zugewiesen
      $this->class_obj = new $class_needed;
  }

  public function config($config, $MSG) {
    $this->msg = $MSG;
    $this->config = $config;
    ### Zeitstempel
    date_default_timezone_set("Europe/Berlin");

    $this->timestamp = time();
    $this->datum = date("Y.m.d",$this->timestamp);
    $this->uhrzeit = date("H-i-s",$this->timestamp);
    $this->zeit 	= $this->datum."--".$this->uhrzeit;
    $this->jahr 	= substr($this->zeit,0,4);
    $this->monat 	= substr($this->zeit,4,2);
    $this->tag 	= substr($this->zeit,6,2);
    $this->stunde = substr($this->zeit,8,2);
    $this->minute = substr($this->zeit,10,2);
    $this->del_older();
  }

  public function schreiben($msg) {
    echo "<div id=\"schreiben\">\n";
    // echo $this->msg['abschaltung'];
    echo "  <span id=\"text1\">$msg</span>\n";
    echo "  <form action=\"index.php?cont=eintragen\" method=\"post\">\n";
    echo "    <textarea name=\"text\" cols=\"40\" rows=\"10\"></textarea>\n<br/><br />\n";
    echo "    <input type=\"submit\" name=\"text_neu\" value=\"".$this->msg['link_erstellen']."\"><br /><br />\n";
    echo "  </form>\n";
    echo "</div>\n";
  }

  public function eintragen($text) {
    #eintragen der Nachricht in DB
    $arr=array();
    $this->genCode($this->config['codelenght']);
    $this->text = $this->encrypt($text,$this->code);

    $arr[]=$this->code;
    $arr[]=$this->text;
    $arr[]=$this->timestamp;
    $arr[]="";
    if ($this->class_obj->insert("INSERT INTO nachrichten (rid,	msg, datum, rdatum) VALUES (?,?,?,?)", $arr)) {
        // $lastInsertId = $this->class_obj->lastInsertId();
        // $insertedRows = $this->class_obj->rowCount();
        echo"
        <div id=\"gespeichert\">\n";
        echo $this->msg['gespeichert1'];
          echo "
          <b><span id=\"hinweis\">".$this->msg['hinweis']."</span><br /><br /></b>
          <!-- Target -->\n
          <div id=\"urlbox\">\n
            <span id=\"url\" >".$this->config['URL'].$this->code."</span><br />\n
          </div>\n
          <!-- Trigger -->\n
          <div class=\"button_container\">\n
          <button class=\"btn\" data-clipboard-target=\"#url\">\n
            <img src=\"assets/clippy.svg\" alt=\"".$this->msg['clipboard']."\">\n
          </button>\n
          </div>\n
          <script src=\"dist/clipboard.min.js\"></script>\n
          <script>\n
            new Clipboard('.btn');\n
          </script>\n

          <b></b><br /><br />\n
          <a href=\"index.php\">".$this->msg['link_weitere']."</a>\n
        </div>\n" ;
        $this->update_sqlcounter();
    }  else  {
        // $meldung = "Eintrag fehlerhaft!<br/>\n";
    }
    // return $meldung;
  }

  public function msg_zeigen($id) {
    $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,gelesen FROM nachrichten WHERE rid = '$id' AND gelesen='0' ");
    $rowCount = $this->class_obj->rowCount();
    echo "<div id=\"anzeigen1\">\n";
    if (count($selected) > 0) {
      echo "<a href=\"index.php?idd=$id\">". $this->msg['neue_Nachricht']."</a>";
    } else {
      echo $this->msg['keine_Nachricht'];
    }
    $this->msg_link();
    echo "</div>\n";
  }

  public function msg_zeigen2($id) {


    //  $this->debug($id);
     $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,gelesen FROM nachrichten WHERE rid = '$id' AND gelesen='0' ");
     $rowCount = $this->class_obj->rowCount();
     echo "<div id=\"anzeigen2\">\n";
     if (count($selected) > 0) {
       $this->class_obj->delete("DELETE FROM nachrichten WHERE id = ?", array($selected[0]['id']));
       echo "<h2>Deine Nachricht... </h2>";
       echo nl2br($this->decrypt($selected[0]['msg'], $id));

      // echo "<span id=\"counter\"></span>";
     } else {
       echo $this->msg['zu_spaet'];
     }
     $this->msg_link();
  }

  private function X_site_reload() {
    // Laufbalken und Reload zu Index.php
    echo"<hr /><a href=\"index.php\">Schlie&szlig;en</a> in <span id=\"counter\"></span> Sekunden<br />";
    echo "<div style=\"width:335px; border:0px solid #000; align:left;\"><img id=\"status\" src=\"spacer.gif\" width=\"10\" height=\"10\" style=\"background-color: #8080FF;\"></div>";
    // echo "<meta http-equiv=\"Refresh\" content=\"".$this->config['clientDelTime']."; url=index.php\">";
    echo "<script type=\"text/javascript\" language=\"JavaScript\">";
    echo "load(".$this->config['clientDelTime'].",0)";
    echo "</script>";
    echo "</div>\n";

  }

  public function alle_zeigen() {

    //  $this->debug($id);
     $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,gelesen FROM nachrichten");
     $rowCount = $this->class_obj->rowCount();
     for ($i=0; $i < $rowCount; $i++) {
       if (count($selected) > 0) {
         echo nl2br($this->decrypt($selected[$i]['msg'], $selected[$i]['rid']))." - ".date("d.m.Y H:i:s", $selected[$i]['datum'])."<hr />";
       }
     }
     $this->msg_link();
  }

  public function del_older() {
     $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,gelesen FROM nachrichten");
     $rowCount = $this->class_obj->rowCount();
     for ($i=0; $i < $rowCount; $i++) {
       if (count($selected) > 0) {
         if($selected[$i]['datum'] < strtotime("-".$this->config['userDelDays']." days")) {
           $this->class_obj->delete("DELETE FROM nachrichten WHERE id = ?", array($selected[$i]['id']));
         }
       }
     }
  }

  private function msg_link() {
     echo "<br /><br /><hr /><br /><a href=\"index.php\">".$this->msg['selbstNachricht']."</a><br /><br /><br />  ";

  }

  public function admin_sql($array, $typ) {
   $this->debug($array);
   $del = array_pop($array);
   foreach ($array as $key => $value) {
     #echo $key."-".$value."<br/>";
     $arr[] = $value;
   }
   switch ($typ) {
     case "config":
       #rsort($array);
       $this->debug($array);
       $this->class_obj->update("UPDATE ".$this->tabellen[4]." SET erinnerung=?,url=?  WHERE id = ? LIMIT 1", array($array['erinnerung'],$array['url'],$array['id']));
       $this->config($this->tabellen,$this->spalten,$this->farben);
     break;
     case "mail_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[3]." WHERE id = ". $arr[0]);
     break;

     case "mail_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[3]." SET adresse=?  WHERE id = ? LIMIT 1", array($arr[1],$arr[0]));
     break;

     case "mail_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[3]." (adresse) VALUES (?)", $arr);
     break;

     case "bereich_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[0]." WHERE id = ". $arr[0]);
     break;

     case "bereich_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[0]." SET bezeichnung=?  WHERE id = ? LIMIT 1",
                 array($arr[1],$arr[0]));
     break;

     case "bereich_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[0]." (bezeichnung) VALUES (?)", $arr);
     break;

     case "tage_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[1]." WHERE id = ". $arr[0]);
     break;

     case "tage_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[1]." SET bereich=?, bezeichnung=?,tage=? WHERE id = ? LIMIT 1",
                 array($arr[1],$arr[2],$arr[3],$arr[0]));
     break;

     case "tage_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[1]." (bereich, bezeichnung, tage) VALUES (?,?,?)", $arr);
     break;
   }
  }

  private	function genCode($characters) {
    $possible = '1234567890abedefghijklmnopqrstuvwxyzABCDEFGHIJKLMNNOPQRSTUVWXYZ';
    $this->code = '';
    $i = 0;
    while ($i < $characters) {
      $this->code .= substr($possible, mt_rand(0, strlen($possible)-1), 1);
      $i++;
    }
    return $this->code;
  }

  private function encrypt($string, $code) {
    $result = '';
    $key=$this->config['salt'].$code;
    for($i = 0; $i < strlen($string); $i++) {
        $char = substr($string, $i, 1);
        $keychar = substr($key, ($i % strlen($key)) - 1, 1);
        $char = chr(ord($char) + ord($keychar));
        $result .= $char;
    }
    #echo "Ergebnis: ".$result."<br>";
    return base64_encode($result);
  }

  private function decrypt($string, $code) {
      $result = '';
      $string = base64_decode($string);
      $key=$this->config['salt'].$code;

      for($i = 0; $i < strlen($string); $i++) {
        	$char = substr($string, $i, 1);
        	$keychar = substr($key, ($i % strlen($key)) - 1, 1);
        	$char = chr(ord($char) - ord($keychar));
        	$result .= $char;
      }
      #echo $result."<br>";
      return $result;
  }

  private function update_sqlcounter() {
    $neuerwert=0;
    $wert = $this->sqlcounter();
    $neuerwert = $wert + 1;
        if ($this->class_obj->update("UPDATE sqlcounter SET sqlcounter=? WHERE id = ? ", array($neuerwert,1))) {
          $updatedRows = $this->class_obj->rowCount();
          $this->meldung=" wurde erfolgreich ge&auml;ndert.\n";
        } else {
          $this->meldung = "Beim &auml;ndern gab es einen Fehler.\n";
        }
      // echo $this->meldung;
    }


  private function update_webcounter() {
    // if ($this->class_obj->update("UPDATE sqlcounter SET sqlcounter=? WHERE id = ? ", array($neuerwert,0))) {
    //   $updatedRows = $this->class_obj->rowCount();
    //   $this->meldung=" wurde erfolgreich ge&auml;ndert.\n";
    // } else {
    //   $this->meldung = "Beim &auml;ndern gab es einen Fehler.\n";
    // }
    // echo $this->meldung;

      }

  public function sqlcounter() {  // 0 = counter, 1 = sqlcounter
    $counter = $this->class_obj->select("SELECT sqlcounter FROM sqlcounter WHERE id='1'");
    $this->sqlcounter = $counter[0]['sqlcounter'];
    return $this->sqlcounter ;
  }

  public function webcounter() {  // 0 = counter, 1 = sqlcounter
    $counter = $this->class_obj->select("SELECT counter FROM counter WHERE id='1'");
    $this->counter = $counter[0]['counter'];
    $this->debug($this->counter);
    return $this->counter ;
  }


  // ----------------------------------------------------------------------------

  public function update($version) {
    echo "<h2>Updates</h2>\n";
    $file = $this->read_dir("update/");
    rsort($file);
    $this->file = $file;
    #$this->debug($file);
    if ($version != "") {
      include("update/".$this->file[$version]);
      echo "<p>Update durchgef&uuml;hrt.</p>";
    } else {
      foreach ($this->file as $key => $value) {
        echo "<a href=\"index.php?cont=admin_update&version=".$key."\">".$value."</a><br>\n";
      }
    }
  }
  // ----------------------------------------------------------------------------

  private function select($typen, $name, $selected="",$default=0) {
    echo "<select size=\"1\" name=\"$name\">\n";
    if (isset($default)AND ($default==1)) { echo "<option  value=\"0\">alle zeigen</option>";}
    foreach ($typen as $typ => $key) {
      echo '<option ';
      if ($key['id'] == $selected) {
        echo " selected ";
      }
      echo "  value=\"".$key['id']."\">".$key['bezeichnung']."</option>\n";
    }
    echo "</select>\n";
  }

  private function read_dir($dir) {
    $handle=opendir($dir);
    while ($file=readdir($handle)){ ## Dir auslesen
      if($file!=".."  ){ ## wenn keine Ordner
        if (!is_dir($file)) {
          $testfile=substr($file,0,1);#echo "erster buchstabe ".$testfile." - $file<br>";
          if ($testfile != ".") { ## wenn die datei keinen punkt vor dem nadeinamen hat
            $gekuerzt = substr($file,-1);
            if ($gekuerzt !="~") {
              #echo "normal:$file - gekuerzt:$gekuerzt<br>";
              $functions[] = $file; #echo "$file<br>";
            }
          }
        }
      }
    }
    closedir($handle);
    return $functions;
  }

  private function debug ($ausgabe="", $array=true) {
  	if ($ausgabe !="") {
  		if (isset($_SESSION['debug']) and ($_SESSION['debug'] == true)) {
  			if (is_string($ausgabe)) { echo "<font color=\"#FF0000\">(".$ausgabe.")</font><br>\n"; }
          if (is_array($ausgabe)) {
    			  if ($array) {
    				  echo "<pre>\n";
    				  print_r($ausgabe);
    				  echo "</pre>\n";
    			  }
  				}

  		}
  	}
  }

// ----------------------------------------------------------------------------
// Klassen ende
}
?>

==> 1.0.tar.gz: 1.0/class/PM.php <==
<?php
class PM {
  // Konstruktor
  public function __construct ($class_needed,$file_ending) {
    // Die Klasse wird eingebunden
      include($class_needed.$file_ending);
    // Es wird eine Instanz der Klasse erzeugt, und "class_obj" zugewiesen
      $this->class_obj = new $class_needed;
      $this->debug($_POST);
      $this->debug($_GET);
  }

  public function config($config, $MSG) {
    $this->msg = $MSG;
    $this->config = $config;
    ### Zeitstempel
    date_default_timezone_set("Europe/Berlin");

    $this->timestamp = time();
    $this->datum = date("Y.m.d",$this->timestamp);
    $this->uhrzeit = date("H-i-s",$this->timestamp);
    $this->zeit 	= $this->datum."--".$this->uhrzeit;
    $this->jahr 	= substr($this->zeit,0,4);
    $this->monat 	= substr($this->zeit,4,2);
    $this->tag 	= substr($this->zeit,6,2);
    $this->stunde = substr($this->zeit,8,2);
    $this->minute = substr($this->zeit,10,2);
    $this->del_older();
  }

  public function schreiben($msg) {
    $typen=array("0"=>"0","1"=>"1","2"=>"2","3"=>"3", );
    echo "<div id=\"schreiben\">\n";
    // echo $this->msg['abschaltung'];
    echo "  <span id=\"text1\">$msg</span>\n";
    echo "  <form action=\"index.php?cont=eintragen\" method=\"post\">\n";
    echo "    <textarea name=\"text\" cols=\"40\" rows=\"10\"></textarea>\n<br/><br />\n";
    echo "    <input type=\"submit\" name=\"text_neu\" value=\"".$this->msg['link_erstellen']."\"><br /><br />\n";
    echo "<hr />\n";
    echo "zus&auml;tzliche Optionen:<br /><br />\n";
    echo "<label for \"pw\">Passwort</label>  <input id=\"pw\" type=\"password\" name=\"passwort\" size=\"8\" />\n";
    echo "    <input id=\"check\" type=\"checkbox\" />\n";
    echo "<label for \"check\"> ".$this->msg['zeigen']."</label><br />\n";
    echo "<span id=\"passworthinweisSender\">".$this->msg['passworthinweisSender']."</span><br />\n";
    echo "<label for \"fehlversuche\">M&ouml;glich Passwortfehlversuche des Empf&auml;nger erlauben.</label>\n";$this->select($typen, "fehlversuche",$this->config['Passwortfehlversuche']);
    echo "  </form>\n";
    echo "<script>\n";
    echo "	var check = document.getElementById(\"check\"),\n";
    echo "		pw = document.getElementById(\"pw\");\n";
    echo "	check.onclick = function() {\n";
    echo "		pw.type = this.checked ? \"text\" : \"password\";\n";
    echo "	};\n";
    echo "</script>\n";
    echo "\n";
    echo "</div>\n";
  }

  public function eintragen($text,$passwort,$fehlversuche) {
    $PW=0;
    #eintragen der Nachricht in DB
    $this->genCode($this->config['codelenght']);
    if($passwort != ""){
      $code=$passwort.$this->code;
      $PW=1;
    } else {
      $code=$this->code;
      $PW=0;
    }
    $arr=array();
    $this->text = $this->encrypt($text,$code);
    echo"code:$code";
    $arr[]=$this->code;
    $arr[]=$this->text;
    $arr[]=$this->timestamp;
    $arr[]="";
    $arr[]=$PW;
    $arr[]=$fehlversuche;
    if ($this->class_obj->insert("INSERT INTO nachrichten (rid,	msg, datum, rdatum, passwort,fehler) VALUES (?,?,?,?,?,?)", $arr)) {
        // $lastInsertId = $this->class_obj->lastInsertId();
        // $insertedRows = $this->class_obj->rowCount();
        $this->debug($arr);
        echo"
        <div id=\"gespeichert\">\n";
        echo $this->msg['gespeichert1'];
          echo "
          <b><span id=\"hinweis\">".$this->msg['hinweis']."</span><br /><br /></b>
          <!-- Target -->\n
          <div id=\"urlbox\">\n
            <span id=\"url\" >".$this->config['URL'].$this->code."</span><br />\n
          </div>\n
          <!-- Trigger -->\n
          <div class=\"button_container\">\n
          <button class=\"btn\" data-clipboard-target=\"#url\">\n
            <img src=\"assets/clippy.svg\" alt=\"".$this->msg['clipboard']."\">\n
          </button>\n
          </div>\n
          <script src=\"dist/clipboard.min.js\"></script>\n
          <script>\n
            new Clipboard('.btn');\n
          </script>\n

          <b></b><br /><br />\n
          <a href=\"index.php\">".$this->msg['link_weitere']."</a>\n
        </div>\n" ;
        $this->update_sqlcounter();
    }  else  {
        // $meldung = "Eintrag fehlerhaft!<br/>\n";
    }
    // return $meldung;
  }

  public function msg_zeigen($id) {
    $selected = $this->class_obj->select("SELECT id,rid,passwort,fehler FROM nachrichten WHERE rid = '$id' ");
    $rowCount = $this->class_obj->rowCount();
    $anzahlVersuche=array(
      0 => "<u>Du hast nur <b>diesen</b> Versuch.</u><br /><br />",
      1 => "<u>Du hast nur <b>einen</b> Versuch.</u><br /><br />",
      2 => "<u>Du hast nur <b>zwei</b> Versuche.</u><br /><br />",
      3 => "<u>Du hast nur <b>drei</b> Versuche.</u><br /><br />",
    );
    if(!isset($_SESSION['fehlversuche'])) {$_SESSION['fehlversuche']=$selected[0]['fehler'];}
    $this->debug($rowCount);
    $this->debug($selected);
    echo "<div id=\"anzeigen1\">\n";
    $this->debug("FV".$_SESSION['fehlversuche']);
    if (count($selected) > 0) {
      if($selected[0]['passwort'] == "1") {
        echo "<form action=\"index.php?idd=$id\" method=\"post\">\n";
        echo "  <span id=\"empfaengerhinweis\">".$this->msg['empfaengerhinweis']."</span>\n";
        echo "  <label for \"pw\">Passwort</label>  <input id=\"pw\" type=\"password\" name=\"passwort\" size=\"8\" />\n";
        echo "  <input id=\"check\" type=\"checkbox\" /><label for \"check\"> ".$this->msg['zeigen']."</label><br />\n";
        echo "  <span id=\"passworthinweis\">".$this->msg['passworthinweisEmpf']."</span><br />\n";
        echo $anzahlVersuche[$_SESSION['fehlversuche']];
        echo "  <input type=\"submit\" name=\"submit\" value=\"".$this->msg['zeigen']."\">\n";
        echo "</form>\n";
        echo "<script>\n";
        echo "	var check = document.getElementById(\"check\"),\n";
        echo "		pw = document.getElementById(\"pw\");\n";
        echo "	check.onclick = function() {\n";
        echo "		pw.type = this.checked ? \"text\" : \"password\";\n";
        echo "	};\n";
        echo "</script>\n";
        // echo "</form>\n";
      } else {
        echo "<a href=\"index.php?idd=$id\">". $this->msg['neue_Nachricht']."</a>";
      }
    } else {
      echo $this->msg['keine_Nachricht'];
    }
    $this->msg_link();
    echo "</div>\n";
  }

  public function msg_zeigen2($id) {
    //  $this->debug($id);
     $selected = $this->class_obj->select("SELECT id,rid,msg,passwort FROM nachrichten WHERE rid = '$id' ");
     $rowCount = $this->class_obj->rowCount();
     if (isset($_POST['passwort'])) {
       $id=$_POST['passwort'].$id;
     }
     echo "<div id=\"anzeigen2\">\n";
     $this->debug($_SESSION['fehlversuche']);
     if (count($selected) > 0) {
       echo "<h2>Deine Nachricht... </h2>";
       $decrypted = $this->decrypt($selected[0]['msg'], $id);
       if ($decrypted == null) {
         $_SESSION['fehlversuche']--;
         if( $_SESSION['fehlversuche'] > 0) {
           echo "Das Passwort war falsch.<br />Der Absender hat dir noch ".$_SESSION['fehlversuche']." Fehlversuche erlaubt.<br />
           <a href=\"index.php?id=$id\">Nochmal eingeben.</a>\n";
         } else {
           echo "Das Passwort war falsch.<br />Der Absender hat dir keine <br />Passwort-Fehlversuche erlaubt.<br />Deshalb wurde die Nachricht gelöscht<br />";
           $this->class_obj->delete("DELETE FROM nachrichten WHERE id = ?", array($selected[0]['id']));
           // echo "Message geleted;";
           session_destroy();
         }
       }
       echo nl2br($decrypted);
       // echo $this->msg['geloescht'];
      // echo "<span id=\"counter\"></span>";
     } else {
       echo $this->msg['zu_spaet'];
     }
     $this->msg_link();
  }

  private function X_site_reload() {
    // Laufbalken und Reload zu Index.php
    echo"<hr /><a href=\"index.php\">Schlie&szlig;en</a> in <span id=\"counter\"></span> Sekunden<br />";
    echo "<div style=\"width:335px; border:0px solid #000; align:left;\"><img id=\"status\" src=\"spacer.gif\" width=\"10\" height=\"10\" style=\"background-color: #8080FF;\"></div>";
    // echo "<meta http-equiv=\"Refresh\" content=\"".$this->config['clientDelTime']."; url=index.php\">";
    echo "<script type=\"text/javascript\" language=\"JavaScript\">";
    echo "load(".$this->config['clientDelTime'].",0)";
    echo "</script>";
    echo "</div>\n";

  }

  public function alle_zeigen() {

    //  $this->debug($id);
     $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,passwort FROM nachrichten");
     $rowCount = $this->class_obj->rowCount();
     for ($i=0; $i < $rowCount; $i++) {
       if (count($selected) > 0) {
         echo nl2br($this->decrypt($selected[$i]['msg'], $selected[$i]['rid']))." - ".date("d.m.Y H:i:s", $selected[$i]['datum'])."<hr />";
       }
     }
     $this->msg_link();
  }

  public function del_older() {
     $selected = $this->class_obj->select("SELECT id,rid,msg,datum,rdatum,passwort FROM nachrichten");
     $rowCount = $this->class_obj->rowCount();
     for ($i=0; $i < $rowCount; $i++) {
       if (count($selected) > 0) {
         if($selected[$i]['datum'] < strtotime("-".$this->config['userDelDays']." days")) {
           $this->class_obj->delete("DELETE FROM nachrichten WHERE id = ?", array($selected[$i]['id']));
         }
       }
     }
  }

  private function msg_link() {
     echo "<br /><br /><hr /><br /><a href=\"index.php\">".$this->msg['selbstNachricht']."</a><br /><br /><br />  ";

  }

  public function admin_sql($array, $typ) {
   $this->debug($array);
   $del = array_pop($array);
   foreach ($array as $key => $value) {
     #echo $key."-".$value."<br/>";
     $arr[] = $value;
   }
   switch ($typ) {
     case "config":
       #rsort($array);
       $this->debug($array);
       $this->class_obj->update("UPDATE ".$this->tabellen[4]." SET erinnerung=?,url=?  WHERE id = ? LIMIT 1", array($array['erinnerung'],$array['url'],$array['id']));
       $this->config($this->tabellen,$this->spalten,$this->farben);
     break;
     case "mail_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[3]." WHERE id = ". $arr[0]);
     break;

     case "mail_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[3]." SET adresse=?  WHERE id = ? LIMIT 1", array($arr[1],$arr[0]));
     break;

     case "mail_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[3]." (adresse) VALUES (?)", $arr);
     break;

     case "bereich_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[0]." WHERE id = ". $arr[0]);
     break;

     case "bereich_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[0]." SET bezeichnung=?  WHERE id = ? LIMIT 1",
                 array($arr[1],$arr[0]));
     break;

     case "bereich_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[0]." (bezeichnung) VALUES (?)", $arr);
     break;

     case "tage_del":
       $this->class_obj->delete("DELETE FROM ".$this->tabellen[1]." WHERE id = ". $arr[0]);
     break;

     case "tage_chg":
       $this->class_obj->update("UPDATE ".$this->tabellen[1]." SET bereich=?, bezeichnung=?,tage=? WHERE id = ? LIMIT 1",
                 array($arr[1],$arr[2],$arr[3],$arr[0]));
     break;

     case "tage_neu":
       $this->class_obj->insert("INSERT INTO ".$this->tabellen[1]." (bereich, bezeichnung, tage) VALUES (?,?,?)", $arr);
     break;
   }
  }

  private	function genCode($characters) {
    $possible = '1234567890abedefghijklmnopqrstuvwxyzABCDEFGHIJKLMNNOPQRSTUVWXYZ';
    $this->code = '';
    $i = 0;
    while ($i < $characters) {
      $this->code .= substr($possible, mt_rand(0, strlen($possible)-1), 1);
      $i++;
    }
    return $this->code;
  }

  private	function encrypt($plaintext, $password) {
      $method = "AES-256-CBC";
      $key = hash('sha256', $password, true);
      $iv = openssl_random_pseudo_bytes(16);

      $ciphertext = openssl_encrypt($plaintext, $method, $key, OPENSSL_RAW_DATA, $iv);
      $hash = hash_hmac('sha256', $ciphertext . $iv, $key, true);

      return base64_encode($iv . $hash . $ciphertext);
  }

  private	function decrypt($encryptedText, $password) {
      $encryptedText = base64_decode($encryptedText);

      $method = "AES-256-CBC";
      $iv = substr($encryptedText, 0, 16);
      $hash = substr($encryptedText, 16, 32);
      $ciphertext = substr($encryptedText, 48);
      $key = hash('sha256', $password, true);

      if (!hash_equals(hash_hmac('sha256', $ciphertext . $iv, $key, true), $hash)) return null;

      return openssl_decrypt($ciphertext, $method, $key, OPENSSL_RAW_DATA, $iv);
  }

  private function update_sqlcounter() {
    $neuerwert=0;
    $wert = $this->sqlcounter();
    $neuerwert = $wert + 1;
        if ($this->class_obj->update("UPDATE sqlcounter SET sqlcounter=? WHERE id = ? ", array($neuerwert,1))) {
          $updatedRows = $this->class_obj->rowCount();
          $this->meldung=" wurde erfolgreich ge&auml;ndert.\n";
        } else {
          $this->meldung = "Beim &auml;ndern gab es einen Fehler.\n";
        }
      // echo $this->meldung;
    }

  private function update_webcounter() {
    // if ($this->class_obj->update("UPDATE sqlcounter SET sqlcounter=? WHERE id = ? ", array($neuerwert,0))) {
    //   $updatedRows = $this->class_obj->rowCount();
    //   $this->meldung=" wurde erfolgreich ge&auml;ndert.\n";
    // } else {
    //   $this->meldung = "Beim &auml;ndern gab es einen Fehler.\n";
    // }
    // echo $this->meldung;

      }

  public function sqlcounter() {  // 0 = counter, 1 = sqlcounter
    $counter = $this->class_obj->select("SELECT sqlcounter FROM sqlcounter WHERE id='1'");
    $this->sqlcounter = $counter[0]['sqlcounter'];
    return $this->sqlcounter ;
  }

  public function webcounter() {  // 0 = counter, 1 = sqlcounter
    $counter = $this->class_obj->select("SELECT counter FROM counter WHERE id='1'");
    $this->counter = $counter[0]['counter'];
    $this->debug($this->counter);
    return $this->counter ;
  }

  private function show_option() {

  }
  // ----------------------------------------------------------------------------

  public function update($version) {
    echo "<h2>Updates</h2>\n";
    $file = $this->read_dir("update/");
    rsort($file);
    $this->file = $file;
    #$this->debug($file);
    if ($version != "") {
      include("update/".$this->file[$version]);
      echo "<p>Update durchgef&uuml;hrt.</p>";
    } else {
      foreach ($this->file as $key => $value) {
        echo "<a href=\"index.php?cont=admin_update&version=".$key."\">".$value."</a><br>\n";
      }
    }
  }
  // ----------------------------------------------------------------------------

  private function select($werte, $name, $selected="", $default=0, $beschriftung="", $KeyOrVal=0) {
    echo "<select size=\"1\" name=\"$name\">\n";
    if (isset($default)AND ($default==1)) { echo "<option ";
      if($selected == 0 ) echo "selected";
      echo " value=\"0\">$beschriftung</option>\n";}
    foreach ($werte as $key => $val) {
      echo '<option ';
      if ($key == $selected) { echo " selected "; }
      echo " value=\"";
      $ausgabe = ($KeyOrVal ==0 ? $key : $val);
      echo $ausgabe;
      echo "\">".$val."</option>\n";
    }
    echo "</select>\n";
  }

  private function read_dir($dir) {
    $handle=opendir($dir);
    while ($file=readdir($handle)){ ## Dir auslesen
      if($file!=".."  ){ ## wenn keine Ordner
        if (!is_dir($file)) {
          $testfile=substr($file,0,1);#echo "erster buchstabe ".$testfile." - $file<br>";
          if ($testfile != ".") { ## wenn die datei keinen punkt vor dem nadeinamen hat
            $gekuerzt = substr($file,-1);
            if ($gekuerzt !="~") {
              #echo "normal:$file - gekuerzt:$gekuerzt<br>";
              $functions[] = $file; #echo "$file<br>";
            }
          }
        }
      }
    }
    closedir($handle);
    return $functions;
  }

  private function debug ($ausgabe="", $array=true) {
  	if ($ausgabe !="") {
  		if (isset($_SESSION['debug']) and ($_SESSION['debug'] == true)) {
  			if (is_string($ausgabe)) { echo "<font color=\"#FF0000\">(".$ausgabe.")</font><br>\n"; }
          if (is_array($ausgabe)) {
    			  if ($array) {
    				  echo "<pre>\n";
    				  print_r($ausgabe);
    				  echo "</pre>\n";
    			  }
  				}

  		}
  	}
  }

// ----------------------------------------------------------------------------
// Klassen ende
}
?>
